@@ -4,8 +4,9 @@ from siridb.connector import SiriDBClient
 from siridb.connector.lib.exceptions import QueryError, InsertError, \
     ServerError, PoolError, AuthenticationError, UserAuthError
 
+
 def config_equals(a, b):
-    if a.get('username') != b.get('username'):
+    if a.get('user') != b.get('user'):
         return False
     if a.get('password') != b.get('password'):
         return False
@@ -16,6 +17,7 @@ def config_equals(a, b):
 
     return True
 
+
 class SiriDB:
     siri = None
     siridb_connected = False
